summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmdockwidget.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:33:36 -0600
commit3c5631f74d1c75204f950140331e10f739082ee9 (patch)
treea2811ff6c81d3c771745cde47734e65b1da3d806 /kpovmodeler/pmdockwidget.h
parent6adb71382c3d5277c3dcbc4ec24c5ff36b4c07ef (diff)
downloadtdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.tar.gz
tdegraphics-3c5631f74d1c75204f950140331e10f739082ee9.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kpovmodeler/pmdockwidget.h')
-rw-r--r--kpovmodeler/pmdockwidget.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kpovmodeler/pmdockwidget.h b/kpovmodeler/pmdockwidget.h
index 612219c3..4378d282 100644
--- a/kpovmodeler/pmdockwidget.h
+++ b/kpovmodeler/pmdockwidget.h
@@ -94,7 +94,7 @@ class TQPixmap;
#ifndef NO_KDE2
class KToolBar;
-class KConfig;
+class TDEConfig;
#else
class TQToolBar;
#endif
@@ -134,12 +134,12 @@ public:
/**
* Provides saving the current configuration. Must be overridden by an inheriting class.
*/
- virtual void saveConfig( KConfig* ){};
+ virtual void saveConfig( TDEConfig* ){};
/**
* Provides loading the current configuration. Must be overridden by an inheriting class
*/
- virtual void loadConfig( KConfig* ){};
+ virtual void loadConfig( TDEConfig* ){};
#endif
protected:
@@ -286,14 +286,14 @@ public:
*
* @param c the configuration safe
*/
- virtual void saveConfig( KConfig* c);
+ virtual void saveConfig( TDEConfig* c);
/**
* Loads the current button state from a KDE config container object.
*
* @param c the configuration safe
*/
- virtual void loadConfig( KConfig* );
+ virtual void loadConfig( TDEConfig* );
#endif
protected slots:
@@ -821,7 +821,7 @@ private:
* that can be called within a @ref PMDockMainWindow or a @ref PMDockWidget .
*
* An important feature is the ability to read or save the current state of all things concerning to
* dockwidgets to @ref KConfig .
*
* The dockmanager is also often used when a certain dockwidget or a child of such dockwidget must be found.
*
@@ -860,9 +860,9 @@ public:
* last but not least some necessary things for recovering the dockmainwindow state.
*
* @param c the KDE configuration saver
* @param group the name of the section in KConfig
*/
- void writeConfig( KConfig* c = 0L, TQString group = TQString() );
+ void writeConfig( TDEConfig* c = 0L, TQString group = TQString() );
/**
* Like writeConfig but reads the whole stuff in.
@@ -878,9 +878,9 @@ public:
* to work, each widget must have a unique name.
*
* @param c the KDE configuration saver
* @param group the name of the section in KConfig
*/
- void readConfig ( KConfig* c = 0L, TQString group = TQString() );
+ void readConfig ( TDEConfig* c = 0L, TQString group = TQString() );
#endif
/**
@@ -1284,20 +1284,20 @@ public:
#ifndef NO_KDE2
/**
* It writes the current dock state in the given section of KConfig.
*
* @param c KDE class for saving configurations
* @param group name of section to write to
*/
- void writeDockConfig( KConfig* c = 0L, TQString group = TQString() );
+ void writeDockConfig( TDEConfig* c = 0L, TQString group = TQString() );
/**
* It reads the current dock state from the given section of KConfig.
*
* @param c KDE class for saving configurations
* @param group name of section to read from
*/
- void readDockConfig ( KConfig* c = 0L, TQString group = TQString() );
+ void readDockConfig ( TDEConfig* c = 0L, TQString group = TQString() );
#endif
/**
@@ -1443,8 +1443,8 @@ public:
void readDockConfig(TQDomElement &base);
#ifndef NO_KDE2
- void writeDockConfig( KConfig* c = 0L, TQString group = TQString() );
- void readDockConfig ( KConfig* c = 0L, TQString group = TQString() );
+ void writeDockConfig( TDEConfig* c = 0L, TQString group = TQString() );
+ void readDockConfig ( TDEConfig* c = 0L, TQString group = TQString() );
#endif
@@ -821,7 +821,7 @@ private:
*
* An important feature is the ability to read or save the current state of all things concerning to
- * dockwidgets to @ref KConfig .
+ * dockwidgets to @ref TDEConfig .
*
* The dockmanager is also often used when a certain dockwidget or a child of such dockwidget must be found.
@@ -860,9 +860,9 @@ public:
*
* @param c the KDE configuration saver
- * @param group the name of the section in KConfig
+ * @param group the name of the section in TDEConfig
*/
@@ -878,9 +878,9 @@ public:
*
* @param c the KDE configuration saver
- * @param group the name of the section in KConfig
+ * @param group the name of the section in TDEConfig
*/
@@ -1284,20 +1284,20 @@ public:
#ifndef NO_KDE2
/**
- * It writes the current dock state in the given section of KConfig.
+ * It writes the current dock state in the given section of TDEConfig.
*
* @param c KDE class for saving configurations
@@ -1284,20 +1284,20 @@ public:
/**
- * It reads the current dock state from the given section of KConfig.
+ * It reads the current dock state from the given section of TDEConfig.
*
* @param c KDE class for saving configurations